pub struct InputEvent {
pub data: u8,
}Expand description
Input event for character devices.
This event is emitted when a character device receives input.
Fields
data: u8pub struct InputEvent {
pub data: u8,
}Input event for character devices.
This event is emitted when a character device receives input.
data: u8